Imports Microsoft.VisualBasic
Imports System
Imports System.Data
Imports System.Data.SqlClient

''' <summary>
''' Represents a family member.
''' </summary>
<Serializable()> _
Public Class Person

    Private _id As Integer
    Private _firstName As String
    Private _lastName As String
    Private _middleName As String
    Private _birthDate As String
    Private _birthLocation As String
    Private _deathDate As String
    Private _deathLocation As String

    ''' <summary>
    ''' Default constructor.
    ''' </summary>
    Public Sub New()
        '
    End Sub
    ''' <summary>
    ''' Constructor using family member attributes as input data.
    ''' </summary>
    ''' <param name="firstName">First name</param>
    ''' <param name="lastName">Last name</param>
    ''' <param name="middleName">Middle name</param>
    ''' <param name="birthDate">Date of birth</param>
    ''' <param name="deathDate">Date of death</param>
    ''' <param name="birthLocation">Birthplace</param>
    ''' <param name="deathLocation">Place of death</param>
    Public Sub New(ByVal firstName As String, ByVal lastName As String, _
        ByVal middleName As String, ByVal birthDate As String, _
        ByVal deathDate As String, ByVal birthLocation As String, _
        ByVal deathLocation As String)

        Me._birthDate = birthDate
        Me._deathDate = deathDate
        Me._firstName = firstName
        Me._lastName = lastName
        Me._middleName = middleName
        Me._deathLocation = deathLocation
        Me._birthLocation = birthLocation
    End Sub

    ''' <summary>
    ''' Constructor using a DataRow as input data.
    ''' </summary>
    ''' <param name="personRow">DataRow containing person data.</param>
    Public Sub New(ByVal personRow As DataRow)
        Me._id = Convert.ToInt16(personRow("personID"))
        Me._birthDate = personRow("birthDate").ToString()
        Me._deathDate = personRow("deathDate").ToString()
        Me._firstName = personRow("firstName").ToString()
        Me._lastName = personRow("lastName").ToString()
        Me._middleName = personRow("middleName").ToString()
        Me._deathLocation = personRow("deathLocation").ToString()
        Me._birthLocation = personRow("birthLocation").ToString()
    End Sub

    ''' <summary>
    ''' Unique identifier for person in database.
    ''' </summary>
    ''' <value></value>
    Public Property ID() As Integer
        Get
            Return Me._id
        End Get
        Set(ByVal value As Integer)
            Me._id = value
        End Set
    End Property
    ''' <summary>
    ''' First name of family member.
    ''' </summary>
    ''' <value>string</value>
    Public Property FirstName() As String
        Get
            Return Me._firstName
        End Get
        Set(ByVal value As String)
            Me._firstName = value
        End Set
    End Property
    ''' <summary>
    ''' Last name of family member.
    ''' </summary>
    ''' <value>string</value>
    Public Property LastName() As String
        Get
            Return Me._lastName
        End Get
        Set(ByVal value As String)
            Me._lastName = value
        End Set
    End Property
    ''' <summary>
    ''' Middle name of family member.
    ''' </summary>
    ''' <value>string</value>
    Public Property MiddleName() As String
        Get
            Return Me._middleName
        End Get
        Set(ByVal value As String)
            Me._middleName = value
        End Set
    End Property
    ''' <summary>
    ''' Date of birth of family member.
    ''' </summary>
    ''' <value>string</value>
    Public Property BirthDate() As String
        Get
            Return Me._birthDate
        End Get
        Set(ByVal value As String)
            Me._birthDate = value
        End Set
    End Property
    ''' <summary>
    ''' Date of death of family member.
    ''' </summary>
    ''' <value>string</value>
    Public Property DeathDate() As String
        Get
            Return Me._deathDate
        End Get
        Set(ByVal value As String)
            Me._deathDate = value
        End Set
    End Property
    ''' <summary>
    ''' Place of birth of family member.
    ''' </summary>
    ''' <value>string</value>
    Public Property BirthLocation() As String
        Get
            Return Me._birthLocation

        End Get
        Set(ByVal value As String)
            Me._birthLocation = value

        End Set
    End Property
    ''' <summary>
    ''' Place of death of family member.
    ''' </summary>
    ''' <value>string</value>
    Public Property DeathLocation() As String
        Get
            Return Me._deathLocation
        End Get
        Set(ByVal value As String)
            Me._deathLocation = value
        End Set
    End Property
End Class


