Imports System.Web
Imports System.Web.Services
Imports System.Web.Services.Protocols
Imports System.Data
Imports System.Data.SqlClient
Imports System.Data.SqlTypes
Imports System.Collections

<WebServiceBinding(ConformsTo:= WsiProfiles.BasicProfile1_1, EmitConformanceClaims:= True)> _
<WebService(Namespace:="uri:family:geneology", Name:="Family History", Description:="Web service for gathering family history data.")> _
Public Class Service
    Inherits System.Web.Services.WebService

    Private Const connectionString As String = "Data Source=.\SQLExpress;Integrated Security=True;AttachDBFilename=C:\WebSites\FamilyHistory_VB\App_Data\Family.mdf;User Instance=True"

    <WebMethod(Description:="Search for family member based on first and last name.")> _
    Public Function FindPerson(ByVal firstName As String, ByVal lastName As String) As Person()
        ' Search database for person based on first name and last name.
        Return SearchPersons(firstName, lastName)
    End Function

    <WebMethod(Description:="Add or update family member information.")> _
    Public Function UpdatePerson(ByVal person As Person) As Integer

        Dim personID As Integer

        If (Person.ID > 0) Then
            ' Update existing person.
            Call RevisePerson(person)
            personID = person.ID
        Else
            ' Add new person.
            personID = AddPerson(person)
        End If

        Return personID
    End Function
    ''' <summary>
    ''' Search database for person(s) based on first name and last name.
    ''' </summary>
    ''' <param name="firstName">First name of family member.</param>
    ''' <param name="lastName">Last name of family member.</param>
    ''' <returns>Zero or more persons.</returns>
    Private Function SearchPersons(ByVal firstName As String, ByVal lastName As String) As Person()

        Dim persons As ArrayList = New ArrayList()
        Dim dataConnection As SqlConnection = New SqlConnection(connectionString)
        Dim searchCommand As SqlCommand = New SqlCommand("dbo.FindPersons", dataConnection)

        searchCommand.CommandType = CommandType.StoredProcedure
        searchCommand.Parameters.AddWithValue("@firstName", firstName)
        searchCommand.Parameters.AddWithValue("@lastName", lastName)

        Dim searchResults As SqlDataAdapter = New SqlDataAdapter(searchCommand)
        Dim personTable As DataTable = New DataTable()

        searchResults.Fill(personTable)

        For i As Integer = 0 To personTable.Rows.Count - 1
            persons.Add(New Person(personTable.Rows(i)))
        Next i

        dataConnection.Close()

        Return CType(persons.ToArray(GetType(Person)), Person())
    End Function
    ''' <summary>
    ''' Add a family member to the database.
    ''' </summary>
    ''' <param name="newPerson">Person object containing family member data.</param>
    ''' <returns>The unique id in the database for the family member.</returns>
    Private Function AddPerson(ByVal newPerson As Person) As Short

        Dim dataConnection As SqlConnection = New SqlConnection(connectionString)
        Dim addCommand As SqlCommand = New SqlCommand("dbo.AddPerson", dataConnection)

        addCommand.CommandType = CommandType.StoredProcedure
        addCommand.Parameters.AddWithValue("@firstName", newPerson.FirstName)
        addCommand.Parameters.AddWithValue("@middleName", newPerson.MiddleName)
        addCommand.Parameters.AddWithValue("@lastName", newPerson.LastName)
        addCommand.Parameters.AddWithValue("@birthDate", newPerson.BirthDate)
        addCommand.Parameters.AddWithValue("@birthLocation", newPerson.BirthLocation)
        addCommand.Parameters.AddWithValue("@deathDate", newPerson.DeathDate)
        addCommand.Parameters.AddWithValue("@deathLocation", newPerson.DeathLocation)

        dataConnection.Open()

        Dim retVal As Short = Convert.ToInt16(addCommand.ExecuteScalar())

        dataConnection.Close()

        Return retVal

    End Function

    ''' <summary>
    ''' Update family member information in database.
    ''' </summary>
    ''' <param name="pdatedPerson">Person object containing family member data.</param>
    Private Sub RevisePerson(ByVal updatedPerson As Person)

        Dim dataConnection As SqlConnection = New SqlConnection(connectionString)
        Dim updateCommand As SqlCommand = New SqlCommand("dbo.UpdatePerson", dataConnection)

        updateCommand.CommandType = CommandType.StoredProcedure
        updateCommand.Parameters.AddWithValue("@id", updatedPerson.ID)
        updateCommand.Parameters.AddWithValue("@firstName", updatedPerson.FirstName)
        updateCommand.Parameters.AddWithValue("@middleName", updatedPerson.MiddleName)
        updateCommand.Parameters.AddWithValue("@lastName", updatedPerson.LastName)
        updateCommand.Parameters.AddWithValue("@birthDate", updatedPerson.BirthDate)
        updateCommand.Parameters.AddWithValue("@birthLocation", updatedPerson.BirthLocation)
        updateCommand.Parameters.AddWithValue("@deathDate", updatedPerson.DeathDate)
        updateCommand.Parameters.AddWithValue("@deathLocation", updatedPerson.DeathLocation)

        dataConnection.Open()

        updateCommand.ExecuteNonQuery()

        dataConnection.Close()
    End Sub

End Class
