using System;
using System.Data;
using System.Data.SqlClient;

/// <summary>
/// Represents a family member.
/// </summary>
[Serializable()]
public class Person
{
    private int _id;
    private string _firstName;
    private string _lastName;
    private string _middleName;
    private string _birthDate;
    private string _birthLocation;
    private string _deathDate;
    private string _deathLocation;

    /// <summary>
    /// Default constructor.
    /// </summary>
    public Person()
	{
	}

    /// <summary>
    /// Constructor using family member attributes as input data.
    /// </summary>
    /// <param name="firstName">First name</param>
    /// <param name="lastName">Last name</param>
    /// <param name="middleName">Middle name</param>
    /// <param name="birthDate">Date of birth</param>
    /// <param name="deathDate">Date of death</param>
    /// <param name="birthLocation">Birthplace</param>
    /// <param name="deathLocation">Place of death</param>
    public Person(string firstName, string lastName,
        string middleName, string birthDate,
        string deathDate, string birthLocation,
        string deathLocation)
    {
        this._birthDate = birthDate;
        this._deathDate = deathDate;
        this._firstName = firstName;
        this._lastName = lastName;
        this._middleName = middleName;
        this._deathLocation = deathLocation;
        this._birthLocation = birthLocation;
    }

    /// <summary>
    /// Constructor using a DataRow as input data.
    /// </summary>
    /// <param name="personRow">DataRow containing person data.</param>
    public Person(DataRow personRow)
    {
        this._id = Convert.ToInt16(personRow["personID"]);
        this._birthDate = personRow["birthDate"].ToString();
        this._deathDate = personRow["deathDate"].ToString();
        this._firstName = personRow["firstName"].ToString();
        this._lastName = personRow["lastName"].ToString();
        this._middleName = personRow["middleName"].ToString();
        this._deathLocation = personRow["deathLocation"].ToString();
        this._birthLocation = personRow["birthLocation"].ToString();
    }
    /// <summary>
    /// Unique identifier for person in database.
    /// </summary>
    /// <value></value>
    public int ID
    {
        get
        {
            return this._id;
        }
        set
        {
            this._id = value;
        }
    }

    /// <summary>
    /// First name of family member.
    /// </summary>
    /// <value>string</value>
    public string FirstName
    {
        get
        {
            return this._firstName;
        }
        set
        {
            this._firstName = value;
        }
    }
    /// <summary>
    /// Last name of family member.
    /// </summary>
    /// <value>string</value>
    public string LastName
    {
        get
        {
            return this._lastName;
        }
        set
        {
            this._lastName = value;
        }
    }
    /// <summary>
    /// Middle name of family member.
    /// </summary>
    /// <value>string</value>
    public string MiddleName
    {
        get
        {
            return this._middleName;
        }
        set
        {
            this._middleName = value;
        }
    }
    /// <summary>
    /// Date of birth of family member.
    /// </summary>
    /// <value>string</value>
    public string BirthDate
    {
        get
        {
            return this._birthDate;
        }
        set
        {
            this._birthDate = value;
        }
    }
    /// <summary>
    /// Date of death of family member.
    /// </summary>
    /// <value>string</value>
    public string DeathDate
    {
        get
        {
            return this._deathDate;
        }
        set
        {
            this._deathDate = value;
        }
    }
    /// <summary>
    /// Place of birth of family member.
    /// </summary>
    /// <value>string</value>
    public string BirthLocation
    {
        get
        {
            return this._birthLocation;
        }
        set
        {
            this._birthLocation = value;
        }
    }

    /// <summary>
    /// Place of death of family member.
    /// </summary>
    /// <value>string</value>
    public string DeathLocation
    {
        get
        {
            return this._deathLocation;
        }
        set
        {
            this._deathLocation = value;
        }
    }
}
