using System;
using System.Web;
using System.Web.Services;
using System.Web.Services.Protocols;
using System.Data;
using System.Data.SqlClient;
using System.Data.SqlTypes;
using System.Collections;

[WebServiceBinding(ConformsTo = WsiProfiles.BasicProfile1_1, EmitConformanceClaims = true)]
[WebService(Namespace = "uri:family:geneology",Name = "Family History", Description = "Web service for gathering family history data." )]
public class Service : System.Web.Services.WebService {

    private const string connectionString = @"Data Source=.\SQLExpress;Integrated Security=True;AttachDBFilename=C:\WebSites\FamilyHistory_VCS\App_Data\Family.mdf;User Instance=True";

    [WebMethod(Description ="Search for family member based on first and last name.") ]
    public Person[] FindPerson(string firstName, string lastName) {
        
        // Search database for person based on first name and last name.
        return SearchPersons(firstName, lastName);
    }

    [WebMethod(Description = "Add or update family member information.") ]
    public int UpdatePerson(Person person)
    {
        int personID;
        if (person.ID > 0)
        {
            // Update existing person.
            RevisePerson(person);
            personID = person.ID;
        }
        else
        {
            // Add new person.
            personID = AddPerson(person);
        }

        return personID;    
    }

    /// <summary>
    /// Search database for person(s) based on first name and last name.
    /// </summary>
    /// <param name="firstName">First name of family member.</param>
    /// <param name="lastName">Last name of family member.</param>
    /// <returns>Zero or more persons.</returns>
    private Person[] SearchPersons(string firstName, string lastName)
    {
        ArrayList persons = new ArrayList();

        using (SqlConnection dataConnection = new SqlConnection(connectionString))
        using (SqlCommand searchCommand = new SqlCommand("dbo.FindPersons", dataConnection))
        {
            searchCommand.CommandType = CommandType.StoredProcedure;
            searchCommand.Parameters.Add("@firstName", firstName);
            searchCommand.Parameters.Add("@lastName", lastName);

            SqlDataAdapter searchResults = new SqlDataAdapter(searchCommand);
            DataTable personTable = new DataTable();
            searchResults.Fill(personTable);
            for (int i=0; i < personTable.Rows.Count; i++)
            {
                persons.Add(new Person(personTable.Rows[i]));
            }
        }
        return (Person[])persons.ToArray(typeof(Person));
    }

    /// <summary>
    /// Add a family member to the database.
    /// </summary>
    /// <param name="newPerson">Person object containing family member data.</param>
    /// <returns>The unique id in the database for the family member.</returns>
    private int AddPerson(Person newPerson)
    {
        using (SqlConnection dataConnection = new SqlConnection(connectionString))
        using (SqlCommand addCommand = new SqlCommand("dbo.AddPerson", dataConnection))
        {
            addCommand.CommandType = CommandType.StoredProcedure;
            addCommand.Parameters.Add("@firstName", newPerson.FirstName);
            addCommand.Parameters.Add("@middleName", newPerson.MiddleName);
            addCommand.Parameters.Add("@lastName", newPerson.LastName);
            addCommand.Parameters.Add("@birthDate", newPerson.BirthDate);
            addCommand.Parameters.Add("@birthLocation", newPerson.BirthLocation);
            addCommand.Parameters.Add("@deathDate", newPerson.DeathDate);
            addCommand.Parameters.Add("@deathLocation", newPerson.DeathLocation);

            dataConnection.Open();

            return Convert.ToInt16(addCommand.ExecuteScalar());
        }
    }

    /// <summary>
    /// Update family member information in database.
    /// </summary>
    /// <param name="pdatedPerson">Person object containing family member data.</param>
    private void RevisePerson(Person updatedPerson)
    {
        using (SqlConnection dataConnection = new SqlConnection(connectionString))
        using (SqlCommand updateCommand = new SqlCommand("dbo.UpdatePerson", dataConnection))
        {
            updateCommand.CommandType = CommandType.StoredProcedure;
            updateCommand.Parameters.Add("@id", updatedPerson.ID);
            updateCommand.Parameters.Add("@firstName", updatedPerson.FirstName);
            updateCommand.Parameters.Add("@middleName", updatedPerson.MiddleName);
            updateCommand.Parameters.Add("@lastName", updatedPerson.LastName);
            updateCommand.Parameters.Add("@birthDate", updatedPerson.BirthDate);
            updateCommand.Parameters.Add("@birthLocation", updatedPerson.BirthLocation);
            updateCommand.Parameters.Add("@deathDate", updatedPerson.DeathDate);
            updateCommand.Parameters.Add("@deathLocation", updatedPerson.DeathLocation);

            dataConnection.Open();
            
            updateCommand.ExecuteNonQuery();
        }
    }

}
